package example.codes;

import com.silanis.esl.sdk.DocumentPackage;
import com.silanis.esl.sdk.DocumentType;
import com.silanis.esl.sdk.EslClient;
import com.silanis.esl.sdk.FastTrackSigner;
import com.silanis.esl.sdk.PackageId;
import com.silanis.esl.sdk.Placeholder;
import com.silanis.esl.sdk.Signer;
import com.silanis.esl.sdk.builder.DocumentBuilder;
import com.silanis.esl.sdk.builder.FastTrackSignerBuilder;
import com.silanis.esl.sdk.builder.SignatureBuilder;
import com.silanis.esl.sdk.builder.SignerBuilder;

import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.InputStream;
import java.text.SimpleDateFormat;
import java.util.Collections;
import java.util.Date;
import java.util.List;

import static com.silanis.esl.sdk.builder.PackageBuilder.newPackageNamed;

public class FastTrack {
	
    public static PackageId templateId;
    public static String signingUrl;

    public static final String TEMPLATE_NAME = "StartFastTrackExample Template: " + new SimpleDateFormat("HH:mm:ss").format(new Date());
    public static final String TEMPLATE_DESCRIPTION = "This is a package created using the eSignLive SDK";
    public static final String TEMPLATE_EMAIL_MESSAGE = "This message should be delivered to all signers";
    public static final String TEMPLATE_SIGNER_FIRST = "John";
    public static final String TEMPLATE_SIGNER_LAST = "Smith";
    public static final String PLACEHOLDER_ID = "PlaceholderId1";

    public static final String FAST_TRACK_SIGNER_FIRST = "Patty";
    public static final String FAST_TRACK_SIGNER_LAST = "Galant";

    public static final String DOCUMENT_NAME = "First Document";
    public static final String DOCUMENT_ID = "doc1";
	
	public static void main (String[] args) throws FileNotFoundException{
		
		MyInfo info = new MyInfo();
		
		EslClient eslClient = new EslClient(info.API_KEY_SANDBOX, info.API_URL_SANDBOX);
		
		String email1 = "mail33@mailinator.com";
		
		Signer signer1 = SignerBuilder.newSignerWithEmail(email1)
                .withFirstName(TEMPLATE_SIGNER_FIRST)
                .withLastName(TEMPLATE_SIGNER_LAST).build();
		
		Signer signer2 = SignerBuilder.newSignerPlaceholder(new Placeholder(PLACEHOLDER_ID)).build();
		
		InputStream documentInputStream1 = new FileInputStream("C:/Users/hhaidary/Desktop/PDFs/doc1.pdf"); 
		
		DocumentPackage template = newPackageNamed(TEMPLATE_NAME)
			.describedAs(TEMPLATE_DESCRIPTION)
			.withEmailMessage(TEMPLATE_EMAIL_MESSAGE)
			.withSigner(signer1)
			.withSigner(signer2)
			.withDocument(DocumentBuilder.newDocumentWithName(DOCUMENT_NAME)
			                       .withId(DOCUMENT_ID)
			                       .fromStream(documentInputStream1, DocumentType.PDF)
			                       .withSignature(SignatureBuilder.signatureFor(email1)
			                                                      .onPage(0)
			                                                      .atPosition(100,100))
			                       .withSignature(SignatureBuilder.signatureFor(new Placeholder(PLACEHOLDER_ID))
			                                                      .onPage(0)
			                                                      .atPosition(400,100))
			                       .build())
			.build();
		
		templateId = eslClient.getTemplateService().createTemplate(template);
		
		FastTrackSigner signer = FastTrackSignerBuilder.newSignerWithId(signer2.getId())
			.withEmail("mail51@mailinator.com")
			.withFirstName(FAST_TRACK_SIGNER_FIRST)
			.withLastName(FAST_TRACK_SIGNER_LAST)
			.build();
		
		signingUrl = eslClient.getPackageService().startFastTrack(templateId, Collections.singletonList(signer));
		
		System.out.println(signingUrl);
		
	}

}
